@@ -43,8 +43,8 @@
  *  
  */
 
-#ifndef SFMT_SSE2_607_1_H
-#define SFMT_SSE2_607_1_H
+#ifndef SFMT_SSE2_607_12_H
+#define SFMT_SSE2_607_12_H
 
 /*
  * code of Christophe Dutang 
@@ -55,17 +55,15 @@
  defined (as follows) since functions _mm_srli_si128 and 
  _mm_srli_epi32 requires immediate values. */
 
-#define POS1_607_1	2
-#define SL1_607_1	15
-#define SL2_607_1	3
-#define SR1_607_1	13
-#define SR2_607_1	3
-
-#include <Rinternals.h>
+#define POS1_607_12 1
+#define SL1_607_12	12
+#define SL2_607_12	7
+#define SR1_607_12	9
+#define SR2_607_12	1
 
 /* =================== end of my code =============== */
 
-PRE_ALWAYS static __m128i mm_recursion_607_1(__m128i *a, __m128i *b, __m128i c,
+PRE_ALWAYS static __m128i mm_recursion_607_12(__m128i *a, __m128i *b, __m128i c,
 				   __m128i d, __m128i mask) ALWAYSINLINE;
 
 /**
@@ -77,22 +75,20 @@ PRE_ALWAYS static __m128i mm_recursion_607_1(__m128i *a, __m128i *b, __m128i c,
  * @param mask 128-bit mask
  * @return output
  */
-PRE_ALWAYS static __m128i mm_recursion_607_1(__m128i *a, __m128i *b, 
+PRE_ALWAYS static __m128i mm_recursion_607_12(__m128i *a, __m128i *b, 
 				   __m128i c, __m128i d, __m128i mask) {
     __m128i v, x, y, z;
     
-    //Rprintf("zog1 \n");
-    
-    x = _mm_load_si128(a);  //Rprintf("zog2 \n");
-    y = _mm_srli_epi32(*b, SR1_607_1);    //Rprintf("zog3 \n");
-    z = _mm_srli_si128(c, SR2_607_1);    //Rprintf("zog4 \n");
-    v = _mm_slli_epi32(d, SL1_607_1);    //Rprintf("zog5 \n");
-    z = _mm_xor_si128(z, x);    //Rprintf("zog6 \n");
-    z = _mm_xor_si128(z, v);    //Rprintf("zog7 \n");
-    x = _mm_slli_si128(x, SL2_607_1);    //Rprintf("zog8 \n");
-    y = _mm_and_si128(y, mask);    //Rprintf("zog9 \n");
-    z = _mm_xor_si128(z, x);    //Rprintf("zog10 \n");
-    z = _mm_xor_si128(z, y);    //Rprintf("zog11 \n");
+    x = _mm_load_si128(a);
+    y = _mm_srli_epi32(*b, SR1_607_12);
+    z = _mm_srli_si128(c, SR2_607_12);
+    v = _mm_slli_epi32(d, SL1_607_12);
+    z = _mm_xor_si128(z, x);
+    z = _mm_xor_si128(z, v);
+    x = _mm_slli_si128(x, SL2_607_12);
+    y = _mm_and_si128(y, mask);
+    z = _mm_xor_si128(z, x);
+    z = _mm_xor_si128(z, y);
     return z;
 }
 
@@ -100,29 +96,21 @@ PRE_ALWAYS static __m128i mm_recursion_607_1(__m128i *a, __m128i *b,
  * This function fills the internal state array with pseudorandom
  * integers.
  */
-inline static void gen_rand_all_607_1(void) {
+inline static void gen_rand_all_607_12(void) {
     int i;
     __m128i r, r1, r2, mask;
-    
-    //Rprintf("mask\n");
-    
     mask = _mm_set_epi32(MSK4, MSK3, MSK2, MSK1);    
     
-    //Rprintf("blii\n");
-    
     r1 = _mm_load_si128(&sfmt[N - 2].si);
     r2 = _mm_load_si128(&sfmt[N - 1].si);
-    for (i = 0; i < N - POS1_607_1; i++) {
-	r = mm_recursion_607_1(&sfmt[i].si, &sfmt[i + POS1_607_1].si, r1, r2, mask);
+    for (i = 0; i < N - POS1_607_12; i++) {
+	r = mm_recursion_607_12(&sfmt[i].si, &sfmt[i + POS1_607_12].si, r1, r2, mask);
 	_mm_store_si128(&sfmt[i].si, r);
 	r1 = r2;
 	r2 = r;
     }
-    
-    //Rprintf("tauoo\n");
-    
     for (; i < N; i++) {
-	r = mm_recursion_607_1(&sfmt[i].si, &sfmt[i + POS1_607_1 - N].si, r1, r2, mask);
+	r = mm_recursion_607_12(&sfmt[i].si, &sfmt[i + POS1_607_12 - N].si, r1, r2, mask);
 	_mm_store_si128(&sfmt[i].si, r);
 	r1 = r2;
 	r2 = r;
@@ -136,48 +124,39 @@ inline static void gen_rand_all_607_1(void) {
  * @param array an 128-bit array to be filled by pseudorandom numbers.  
  * @param size number of 128-bit pesudorandom numbers to be generated.
  */
-inline static void gen_rand_array_607_1(w128_t *array, int size) {
+inline static void gen_rand_array_607_12(w128_t *array, int size) {
     int i, j;
     __m128i r, r1, r2, mask;
     mask = _mm_set_epi32(MSK4, MSK3, MSK2, MSK1);
-    
-    //Rprintf("mask\n");
-    
+
     r1 = _mm_load_si128(&sfmt[N - 2].si);
     r2 = _mm_load_si128(&sfmt[N - 1].si);
-        //Rprintf("tauoo1\n");
-    
-    for (i = 0; i < N - POS1_607_1; i++) {
-	r = mm_recursion_607_1(&sfmt[i].si, &sfmt[i + POS1_607_1].si, r1, r2, mask);
+    for (i = 0; i < N - POS1_607_12; i++) {
+	r = mm_recursion_607_12(&sfmt[i].si, &sfmt[i + POS1_607_12].si, r1, r2, mask);
 	_mm_store_si128(&array[i].si, r);
-        //Rprintf("i : %d\t");
 	r1 = r2;
 	r2 = r;
     }
-        //Rprintf("tauoo2\n");
     for (; i < N; i++) {
-	r = mm_recursion_607_1(&sfmt[i].si, &array[i + POS1_607_1 - N].si, r1, r2, mask);
+	r = mm_recursion_607_12(&sfmt[i].si, &array[i + POS1_607_12 - N].si, r1, r2, mask);
 	_mm_store_si128(&array[i].si, r);
 	r1 = r2;
 	r2 = r;
     }
-        //Rprintf("tauoo3\n");
     /* main loop */
     for (; i < size - N; i++) {
-	r = mm_recursion_607_1(&array[i - N].si, &array[i + POS1_607_1 - N].si, r1, r2,
+	r = mm_recursion_607_12(&array[i - N].si, &array[i + POS1_607_12 - N].si, r1, r2,
 			 mask);
 	_mm_store_si128(&array[i].si, r);
 	r1 = r2;
 	r2 = r;
     }
-        //Rprintf("tauoo4\n");
     for (j = 0; j < 2 * N - size; j++) {
 	r = _mm_load_si128(&array[j + size - N].si);
 	_mm_store_si128(&sfmt[j].si, r);
     }
-        //Rprintf("tauoo5\n");
     for (; i < size; i++) {
-	r = mm_recursion_607_1(&array[i - N].si, &array[i + POS1_607_1 - N].si, r1, r2,
+	r = mm_recursion_607_12(&array[i - N].si, &array[i + POS1_607_12 - N].si, r1, r2,
 			 mask);
 	_mm_store_si128(&array[i].si, r);
 	_mm_store_si128(&sfmt[j++].si, r);
